aboutsummaryrefslogtreecommitdiffstats
path: root/lds/commons.go
diff options
context:
space:
mode:
Diffstat (limited to 'lds/commons.go')
-rw-r--r--lds/commons.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/lds/commons.go b/lds/commons.go
index df94d35b1..29a8f8d66 100644
--- a/lds/commons.go
+++ b/lds/commons.go
@@ -30,8 +30,8 @@ import (
"github.com/dexon-foundation/dexon/params"
)
-// lesCommons contains fields needed by both server and client.
-type lesCommons struct {
+// ldsCommons contains fields needed by both server and client.
+type ldsCommons struct {
config *eth.Config
iConfig *light.IndexerConfig
chainDb ethdb.Database
@@ -51,7 +51,7 @@ type NodeInfo struct {
}
// makeProtocols creates protocol descriptors for the given LES versions.
-func (c *lesCommons) makeProtocols(versions []uint) []p2p.Protocol {
+func (c *ldsCommons) makeProtocols(versions []uint) []p2p.Protocol {
protos := make([]p2p.Protocol, len(versions))
for i, version := range versions {
version := version
@@ -75,7 +75,7 @@ func (c *lesCommons) makeProtocols(versions []uint) []p2p.Protocol {
}
// nodeInfo retrieves some protocol metadata about the running host node.
-func (c *lesCommons) nodeInfo() interface{} {
+func (c *ldsCommons) nodeInfo() interface{} {
var cht params.TrustedCheckpoint
sections, _, _ := c.chtIndexer.Sections()
sections2, _, _ := c.bloomTrieIndexer.Sections()